=========
Changelog
=========

Version 0.1.0 (2023-1-11)
=========================

* First release on PyPI.

Version 0.1.1 (2023-1-15)
=========================

* Updated documentation
* Small code improvements
* Added PyScaffold and pre-commit

Version 0.1.2 (2023-1-18)
=========================

* Updated several links
* Added pytest test cases with code coverage
